@@ -28,6 +28,7 @@
 #include "ContextUtils.h"
 #include "StmtBodyRange.h"
 
+#include <clang/AST/Expr.h>
 #include <clang/AST/StmtCXX.h>
 #include <clang/AST/ASTContext.h>
 #include <clang/AST/DeclCXX.h>
@@ -39,6 +40,7 @@
 #include <clang/AST/ParentMap.h>
 #include <clang/Lex/Lexer.h>
 
+#include <cctype>
 #include <sstream>
 
 using namespace clang;
@@ -46,7 +48,7 @@ using namespace std;
 
 bool Utils::hasConstexprCtor(CXXRecordDecl *decl)
 {
-    return clazy_std::any_of(decl->ctors(), [](CXXConstructorDecl *ctor) {
+    return clazy::any_of(decl->ctors(), [](CXXConstructorDecl *ctor) {
         return ctor->isConstexpr();
     });
 }
@@ -55,6 +57,13 @@ CXXRecordDecl * Utils::namedCastInnerDecl(CXXNamedCastExpr *staticOrDynamicCast)
 {
     Expr *e = staticOrDynamicCast->getSubExpr();
     if (!e) return nullptr;
+    if (auto implicitCast = dyn_cast<ImplicitCastExpr>(e)) {
+        // Sometimes it's automatically cast to base
+        if (implicitCast->getCastKind() == CK_DerivedToBase) {
+            e = implicitCast->getSubExpr();
+        }
+    }
+
     QualType qt = e->getType();
     const Type *t = qt.getTypePtrOrNull();
     if (!t) return nullptr;
@@ -87,7 +96,7 @@ bool Utils::allChildrenMemberCallsConst(Stmt *stm)
             return false;
     }
 
-    return clazy_std::all_of(stm->children(), [](Stmt *child) {
+    return clazy::all_of(stm->children(), [](Stmt *child) {
         return allChildrenMemberCallsConst(child);
     });
 }
@@ -105,24 +114,23 @@ bool Utils::childsHaveSideEffects(Stmt *stm)
     if (binary && (binary->isAssignmentOp() || binary->isShiftAssignOp() || binary->isCompoundAssignmentOp()))
         return true;
 
-    static std::vector<std::string> method_blacklist;
-    if (method_blacklist.empty()) {
-        method_blacklist.push_back("isDestroyed");
-        method_blacklist.push_back("isRecursive"); // TODO: Use qualified name instead ?
-        method_blacklist.push_back("q_func");
-        method_blacklist.push_back("d_func");
-        method_blacklist.push_back("begin");
-        method_blacklist.push_back("end");
-        method_blacklist.push_back("data");
-        method_blacklist.push_back("fragment");
-        method_blacklist.push_back("glIsRenderbuffer");
-    }
+    static const std::vector<StringRef> method_blacklist = {
+        "isDestroyed",
+        "isRecursive", // TODO: Use qualified name instead ?
+        "q_func",
+        "d_func",
+        "begin",
+        "end",
+        "data",
+        "fragment",
+        "glIsRenderbuffer"
+    };
 
     auto memberCall = dyn_cast<MemberExpr>(stm);
     if (memberCall) {
         auto methodDecl = dyn_cast<CXXMethodDecl>(memberCall->getMemberDecl());
         if (methodDecl && !methodDecl->isConst() && !methodDecl->isStatic() &&
-                !clazy_std::contains(method_blacklist, methodDecl->getNameAsString()))
+                !clazy::contains(method_blacklist, clazy::name(methodDecl)))
             return true;
     }
 
@@ -134,7 +142,7 @@ bool Utils::childsHaveSideEffects(Stmt *stm)
             return true;
     }*/
 
-    return clazy_std::any_of(stm->children(), [](Stmt *s) {
+    return clazy::any_of(stm->children(), [](Stmt *s) {
         return childsHaveSideEffects(s);
     });
 }
@@ -180,8 +188,8 @@ ValueDecl *Utils::valueDeclForMemberCall(CXXMemberCallExpr *memberCall)
     }
 
     // Maybe there's an implicit cast in between..
-    auto memberExprs = HierarchyUtils::getStatements<MemberExpr>(implicitObject, nullptr, {}, /**depth=*/ 1, /*includeParent=*/ true);
-    auto declRefs = HierarchyUtils::getStatements<DeclRefExpr>(implicitObject, nullptr, {}, /**depth=*/ 1, /*includeParent=*/ true);
+    auto memberExprs = clazy::getStatements<MemberExpr>(implicitObject, nullptr, {}, /**depth=*/ 1, /*includeParent=*/ true);
+    auto declRefs = clazy::getStatements<DeclRefExpr>(implicitObject, nullptr, {}, /**depth=*/ 1, /*includeParent=*/ true);
 
     if (!memberExprs.empty()) {
         return memberExprs.at(0)->getMemberDecl();
@@ -202,7 +210,7 @@ ValueDecl *Utils::valueDeclForOperatorCall(CXXOperatorCallExpr *operatorCall)
     // CXXOperatorCallExpr doesn't have API to access the value decl.
     // By inspecting several ASTs I noticed it's always in the 2nd child
 
-    Stmt *child2 = clazy_std::childAt(operatorCall, 1);
+    Stmt *child2 = clazy::childAt(operatorCall, 1);
     if (!child2)
         return nullptr;
 
@@ -210,7 +218,7 @@ ValueDecl *Utils::valueDeclForOperatorCall(CXXOperatorCallExpr *operatorCall)
         return memberExpr->getMemberDecl();
     } else {
         vector<DeclRefExpr*> refs;
-        HierarchyUtils::getChilds<DeclRefExpr>(child2, refs);
+        clazy::getChilds<DeclRefExpr>(child2, refs);
         if (refs.size() == 1) {
             return refs[0]->getDecl();
         }
@@ -230,41 +238,60 @@ clang::ValueDecl * Utils::valueDeclForCallExpr(clang::CallExpr *expr)
     return nullptr;
 }
 
-
-bool Utils::containsNonConstMemberCall(Stmt *body, const VarDecl *varDecl)
+static bool referencesVar(Stmt *s, const VarDecl *varDecl)
 {
-    std::vector<CXXMemberCallExpr*> memberCalls;
-    HierarchyUtils::getChilds<CXXMemberCallExpr>(body, memberCalls);
+    // look for a DeclRefExpr that references varDecl
+    while (s) {
+        auto it = s->child_begin();
+        Stmt *child = it == s->child_end() ? nullptr : *it;
+        if (auto declRef = dyn_cast_or_null<DeclRefExpr>(child)) {
+            if (declRef->getDecl() == varDecl)
+                return true;
+        }
+        s = child;
+    }
 
-    for (CXXMemberCallExpr *memberCall : memberCalls) {
-        CXXMethodDecl *methodDecl = memberCall->getMethodDecl();
-        if (!methodDecl || methodDecl->isConst())
-            continue;
+    return false;
+}
+
 
-        ValueDecl *valueDecl = Utils::valueDeclForMemberCall(memberCall);
-        if (!valueDecl)
-            continue;
+bool Utils::containsNonConstMemberCall(clang::ParentMap *map, Stmt *body, const VarDecl *varDecl)
+{
+    if (!varDecl)
+        return false;
 
-        if (valueDecl == varDecl)
-            return true;
+    std::vector<CXXMemberCallExpr*> memberCallExprs;
+    clazy::getChilds<CXXMemberCallExpr>(body, memberCallExprs);
+    for (auto memberCall : memberCallExprs) {
+        CXXMethodDecl *methodDecl = memberCall->getMethodDecl();
+        if (methodDecl && !methodDecl->isConst()) {
+            ValueDecl *valueDecl = Utils::valueDeclForMemberCall(memberCall);
+            if (valueDecl == varDecl)
+                return true;
+        }
     }
 
-    // Check for operator calls:
     std::vector<CXXOperatorCallExpr*> operatorCalls;
-    HierarchyUtils::getChilds<CXXOperatorCallExpr>(body, operatorCalls);
-    for (CXXOperatorCallExpr *operatorExpr : operatorCalls) {
-        FunctionDecl *fDecl = operatorExpr->getDirectCallee();
-        if (!fDecl)
-            continue;
-        CXXMethodDecl *methodDecl = dyn_cast<CXXMethodDecl>(fDecl);
-        if (methodDecl == nullptr || methodDecl->isConst())
+    clazy::getChilds<CXXOperatorCallExpr>(body, operatorCalls);
+    for (auto operatorCall : operatorCalls) {
+        FunctionDecl *fDecl = operatorCall->getDirectCallee();
+        if (fDecl) {
+            auto methodDecl = dyn_cast<CXXMethodDecl>(fDecl);
+            if (methodDecl && !methodDecl->isConst()) {
+                ValueDecl *valueDecl = Utils::valueDeclForOperatorCall(operatorCall);
+                if (valueDecl == varDecl)
+                    return true;
+            }
+        }
+    }
+
+    std::vector<BinaryOperator*> assignmentOperators;
+    clazy::getChilds<BinaryOperator>(body, assignmentOperators);
+    for (auto op : assignmentOperators) {
+        if (!op->isAssignmentOp())
             continue;
 
-        ValueDecl *valueDecl = Utils::valueDeclForOperatorCall(operatorExpr);
-        if (!valueDecl)
-            continue;
-
-        if (valueDecl == varDecl)
+        if (referencesVar(op, varDecl))
             return true;
     }
 
@@ -277,9 +304,9 @@ static bool isArgOfFunc(T expr, FunctionDecl *fDecl, const VarDecl *varDecl, boo
     unsigned int param = -1;
     for (auto arg : expr->arguments()) {
         ++param;
-        DeclRefExpr *refExpr = dyn_cast<DeclRefExpr>(arg);
+        auto refExpr = dyn_cast<DeclRefExpr>(arg);
         if (!refExpr)  {
-            if (clazy_std::hasChildren(arg)) {
+            if (clazy::hasChildren(arg)) {
                 Stmt* firstChild = *(arg->child_begin()); // Can be null (bug #362236)
                 refExpr = firstChild ? dyn_cast<DeclRefExpr>(firstChild) : nullptr;
                 if (!refExpr)
@@ -324,7 +351,7 @@ bool Utils::isPassedToFunction(const StmtBodyRange &bodyRange, const VarDecl *va
 
     Stmt *body = bodyRange.body;
     std::vector<CallExpr*> callExprs;
-    HierarchyUtils::getChilds<CallExpr>(body, callExprs);
+    clazy::getChilds<CallExpr>(body, callExprs);
     for (CallExpr *callexpr : callExprs) {
         if (bodyRange.isOutsideRange(callexpr))
             continue;
@@ -338,7 +365,7 @@ bool Utils::isPassedToFunction(const StmtBodyRange &bodyRange, const VarDecl *va
     }
 
     std::vector<CXXConstructExpr*> constructExprs;
-    HierarchyUtils::getChilds<CXXConstructExpr>(body, constructExprs);
+    clazy::getChilds<CXXConstructExpr>(body, constructExprs);
     for (CXXConstructExpr *constructExpr : constructExprs) {
         if (bodyRange.isOutsideRange(constructExpr))
             continue;
@@ -355,12 +382,12 @@ bool Utils::addressIsTaken(const clang::CompilerInstance &ci, Stmt *body, const
     if (!body || !valDecl)
         return false;
 
-    auto unaries = HierarchyUtils::getStatements<UnaryOperator>(body);
-    return clazy_std::any_of(unaries, [valDecl](UnaryOperator *op) {
+    auto unaries = clazy::getStatements<UnaryOperator>(body);
+    return clazy::any_of(unaries, [valDecl](UnaryOperator *op) {
         if (op->getOpcode() != clang::UO_AddrOf)
             return false;
 
-        auto declRef = HierarchyUtils::getFirstChildOfType<DeclRefExpr>(op);
+        auto declRef = clazy::getFirstChildOfType<DeclRefExpr>(op);
         return declRef && declRef->getDecl() == valDecl;
     });
 }
@@ -371,13 +398,13 @@ bool Utils::isAssignedTo(Stmt *body, const VarDecl *varDecl)
         return false;
 
     std::vector<CXXOperatorCallExpr*> operatorCalls;
-    HierarchyUtils::getChilds<CXXOperatorCallExpr>(body, operatorCalls);
+    clazy::getChilds<CXXOperatorCallExpr>(body, operatorCalls);
     for (CXXOperatorCallExpr *operatorExpr : operatorCalls) {
         FunctionDecl *fDecl = operatorExpr->getDirectCallee();
         if (!fDecl)
             continue;
 
-        CXXMethodDecl *methodDecl = dyn_cast<CXXMethodDecl>(fDecl);
+        auto methodDecl = dyn_cast<CXXMethodDecl>(fDecl);
         if (methodDecl && methodDecl->isCopyAssignmentOperator()) {
             ValueDecl *valueDecl = Utils::valueDeclForOperatorCall(operatorExpr);
             if (valueDecl == varDecl)
@@ -391,7 +418,7 @@ bool Utils::isAssignedTo(Stmt *body, const VarDecl *varDecl)
 bool Utils::callHasDefaultArguments(clang::CallExpr *expr)
 {
     std::vector<clang::CXXDefaultArgExpr*> exprs;
-    HierarchyUtils::getChilds<clang::CXXDefaultArgExpr>(expr, exprs, 1);
+    clazy::getChilds<clang::CXXDefaultArgExpr>(expr, exprs, 1);
     return !exprs.empty();
 }
 
@@ -401,7 +428,7 @@ bool Utils::containsStringLiteral(Stmt *stm, bool allowEmpty, int depth)
         return false;
 
     std::vector<StringLiteral*> stringLiterals;
-    HierarchyUtils::getChilds<StringLiteral>(stm, stringLiterals, depth);
+    clazy::getChilds<StringLiteral>(stm, stringLiterals, depth);
 
     if (allowEmpty)
         return !stringLiterals.empty();
@@ -434,48 +461,50 @@ bool Utils::ternaryOperatorIsOfStringLiteral(ConditionalOperator *ternary)
     return true;
 }
 
-bool Utils::isAssignOperator(CXXOperatorCallExpr *op, const std::string &className,
-                             const std::string &argumentType, const clang::LangOptions &lo)
+bool Utils::isAssignOperator(CXXOperatorCallExpr *op, StringRef className,
+                             StringRef argumentType, const clang::LangOptions &lo)
 {
     if (!op)
         return false;
 
     FunctionDecl *functionDecl = op->getDirectCallee();
-    if (!functionDecl)
+    if (!functionDecl || functionDecl->param_size() != 1 )
         return false;
 
-    CXXMethodDecl *methodDecl = dyn_cast<clang::CXXMethodDecl>(functionDecl);
-    if (!className.empty() && !StringUtils::isOfClass(methodDecl, className))
-        return false;
-
-    if (functionDecl->getNameAsString() != "operator=" || functionDecl->param_size() != 1)
-        return false;
-
-    if (!argumentType.empty() && !StringUtils::hasArgumentOfType(functionDecl, argumentType, lo)) {
-        return false;
+    if (!className.empty()) {
+        auto methodDecl = dyn_cast<clang::CXXMethodDecl>(functionDecl);
+        if (!clazy::isOfClass(methodDecl, className))
+            return false;
     }
 
+    if (functionDecl->getNameAsString() != "operator=")
+        return false;
+
+    if (!argumentType.empty() && !clazy::hasArgumentOfType(functionDecl, argumentType, lo))
+        return false;
+
+
     return true;
 }
 
 
 bool Utils::isImplicitCastTo(Stmt *s, const string &className)
 {
-    ImplicitCastExpr *expr = dyn_cast<ImplicitCastExpr>(s);
+    auto expr = dyn_cast<ImplicitCastExpr>(s);
     if (!expr)
         return false;
 
     auto record = expr->getBestDynamicClassType();
-    return record && record->getNameAsString() == className;
+    return record && clazy::name(record) == className;
 }
 
 
-bool Utils::isInsideOperatorCall(ParentMap *map, Stmt *s, const std::vector<string> &anyOf)
+bool Utils::isInsideOperatorCall(ParentMap *map, Stmt *s, const std::vector<StringRef> &anyOf)
 {
     if (!s)
         return false;
 
-    CXXOperatorCallExpr *oper = dyn_cast<CXXOperatorCallExpr>(s);
+    auto oper = dyn_cast<CXXOperatorCallExpr>(s);
     if (oper) {
         auto func = oper->getDirectCallee();
         if (func) {
@@ -485,34 +514,34 @@ bool Utils::isInsideOperatorCall(ParentMap *map, Stmt *s, const std::vector<stri
             auto method = dyn_cast<CXXMethodDecl>(func);
             if (method) {
                 auto record = method->getParent();
-                if (record && clazy_std::contains(anyOf, record->getNameAsString()))
+                if (record && clazy::contains(anyOf, clazy::name(record)))
                     return true;
             }
         }
     }
 
-    return isInsideOperatorCall(map, HierarchyUtils::parent(map, s), anyOf);
+    return isInsideOperatorCall(map, clazy::parent(map, s), anyOf);
 }
 
 
-bool Utils::insideCTORCall(ParentMap *map, Stmt *s, const std::vector<string> &anyOf)
+bool Utils::insideCTORCall(ParentMap *map, Stmt *s, const std::vector<llvm::StringRef> &anyOf)
 {
     if (!s)
         return false;
 
-    CXXConstructExpr *expr = dyn_cast<CXXConstructExpr>(s);
-    if (expr && expr->getConstructor() && clazy_std::contains(anyOf, expr->getConstructor()->getNameAsString())) {
+    auto expr = dyn_cast<CXXConstructExpr>(s);
+    if (expr && expr->getConstructor() && clazy::contains(anyOf, clazy::name(expr->getConstructor()))) {
         return true;
     }
 
-    return insideCTORCall(map, HierarchyUtils::parent(map, s), anyOf);
+    return insideCTORCall(map, clazy::parent(map, s), anyOf);
 }
 
 bool Utils::presumedLocationsEqual(const clang::PresumedLoc &l1, const clang::PresumedLoc &l2)
 {
     return l1.isValid() && l2.isValid() && l1.getColumn() == l2.getColumn() &&
            l1.getLine()   == l2.getLine()   &&
-            string(l1.getFilename()) == string(l2.getFilename());
+            StringRef(l1.getFilename()) == StringRef(l2.getFilename());
 }
 
 CXXRecordDecl *Utils::isMemberVariable(ValueDecl *decl)
@@ -526,8 +555,8 @@ std::vector<CXXMethodDecl *> Utils::methodsFromString(const CXXRecordDecl *recor
         return {};
 
     vector<CXXMethodDecl *> methods;
-    clazy_std::append_if(record->methods(), methods, [methodName](CXXMethodDecl *m) {
-        return m->getNameAsString() == methodName;
+    clazy::append_if(record->methods(), methods, [methodName](CXXMethodDecl *m) {
+        return clazy::name(m) == methodName;
     });
 
     // Also include the base classes
@@ -536,7 +565,7 @@ std::vector<CXXMethodDecl *> Utils::methodsFromString(const CXXRecordDecl *recor
         if (t) {
             auto baseMethods = methodsFromString(t->getAsCXXRecordDecl(), methodName);
             if (!baseMethods.empty())
-                clazy_std::append(baseMethods, methods);
+                clazy::append(baseMethods, methods);
         }
     }
 
@@ -594,9 +623,9 @@ bool Utils::isInDerefExpression(Stmt *s, ParentMap *map)
 
     Stmt *p = s;
     do {
-        p = HierarchyUtils::parent(map, p);
-        CXXOperatorCallExpr *op = p ? dyn_cast<CXXOperatorCallExpr>(p) : nullptr;
-        if (op && op->getDirectCallee() && op->getDirectCallee()->getNameAsString() == "operator*") {
+        p = clazy::parent(map, p);
+        auto op = p ? dyn_cast<CXXOperatorCallExpr>(p) : nullptr;
+        if (op && op->getOperator() == OO_Star) {
             return op;
         }
     } while (p);
@@ -610,12 +639,11 @@ std::vector<CallExpr *> Utils::callListForChain(CallExpr *lastCallExpr)
         return {};
 
     const bool isOperator = isa<CXXOperatorCallExpr>(lastCallExpr);
-
     vector<CallExpr *> callexprs = { lastCallExpr };
     Stmt *s = lastCallExpr;
     do {
         const int childCount = std::distance(s->child_begin(), s->child_end());
-        if (isOperator && childCount > 1) {
+        if (isOperator && childCount > 1 && s == lastCallExpr) {
             // for operator case, the chained call childs are in the second child
             s = *(++s->child_begin());
         } else {
@@ -623,12 +651,17 @@ std::vector<CallExpr *> Utils::callListForChain(CallExpr *lastCallExpr)
         }
 
         if (s) {
-            CallExpr *callExpr = dyn_cast<CallExpr>(s);
+            auto callExpr = dyn_cast<CallExpr>(s);
             if (callExpr && callExpr->getCalleeDecl()) {
                 callexprs.push_back(callExpr);
-            } else if (MemberExpr *memberExpr = dyn_cast<MemberExpr>(s)) {
+            } else if (auto memberExpr = dyn_cast<MemberExpr>(s)) {
                 if (isa<FieldDecl>(memberExpr->getMemberDecl()))
                     break; // accessing a public member via . or -> breaks the chain
+            } else if (isa<ConditionalOperator>(s)) {
+                // Gets very greasy with conditional operators
+                // This would match: (should() ? container1 : container2).append()
+                // and it would return { append(), should()}
+                break;
             }
         }
     } while (s);
@@ -678,7 +711,7 @@ bool Utils::hasMember(CXXRecordDecl *record, const string &memberTypeName)
         const Type *t = qt.getTypePtrOrNull();
         if (t && t->getAsCXXRecordDecl()) {
             CXXRecordDecl *rec = t->getAsCXXRecordDecl();
-            if (rec->getNameAsString() == memberTypeName)
+            if (clazy::name(rec) == memberTypeName)
                 return true;
         }
     }
@@ -689,7 +722,7 @@ bool Utils::hasMember(CXXRecordDecl *record, const string &memberTypeName)
 bool Utils::isSharedPointer(CXXRecordDecl *record)
 {
     static const vector<string> names = { "std::shared_ptr", "QSharedPointer", "boost::shared_ptr" };
-    return record ? clazy_std::contains(names, record->getQualifiedNameAsString()) : false;
+    return record ? clazy::contains(names, record->getQualifiedNameAsString()) : false;
 }
 
 bool Utils::isInitializedExternally(clang::VarDecl *varDecl)
@@ -698,27 +731,25 @@ bool Utils::isInitializedExternally(clang::VarDecl *varDecl)
         return false;
 
     DeclContext *context = varDecl->getDeclContext();
-    FunctionDecl *fDecl = context ? dyn_cast<FunctionDecl>(context) : nullptr;
+    auto fDecl = context ? dyn_cast<FunctionDecl>(context) : nullptr;
     Stmt *body = fDecl ? fDecl->getBody() : nullptr;
     if (!body)
         return false;
 
     vector<DeclStmt*> declStmts;
-    HierarchyUtils::getChilds<DeclStmt>(body, declStmts);
+    clazy::getChilds<DeclStmt>(body, declStmts);
     for (DeclStmt *declStmt : declStmts) {
         if (referencesVarDecl(declStmt, varDecl)) {
             vector<DeclRefExpr*> declRefs;
 
-            HierarchyUtils::getChilds<DeclRefExpr>(declStmt, declRefs);
-            if (!declRefs.empty()) {
+            clazy::getChilds<DeclRefExpr>(declStmt, declRefs);
+            if (!declRefs.empty())
                 return true;
-            }
 
             vector<CallExpr*> callExprs;
-            HierarchyUtils::getChilds<CallExpr>(declStmt, callExprs);
-            if (!callExprs.empty()) {
+            clazy::getChilds<CallExpr>(declStmt, callExprs);
+            if (!callExprs.empty())
                 return true;
-            }
         }
     }
 
@@ -728,7 +759,7 @@ bool Utils::isInitializedExternally(clang::VarDecl *varDecl)
 bool Utils::functionHasEmptyBody(clang::FunctionDecl *func)
 {
     Stmt *body = func ? func->getBody() : nullptr;
-    return !clazy_std::hasChildren(body);
+    return !clazy::hasChildren(body);
 }
 
 clang::Expr *Utils::isWriteOperator(Stmt *stm)
@@ -736,8 +767,7 @@ clang::Expr *Utils::isWriteOperator(Stmt *stm)
     if (!stm)
         return nullptr;
 
-    if (UnaryOperator *up = dyn_cast<UnaryOperator>(stm)) {
-
+    if (auto up = dyn_cast<UnaryOperator>(stm)) {
         auto opcode = up->getOpcode();
         if (opcode == clang::UO_AddrOf || opcode == clang::UO_Deref)
             return nullptr;
@@ -745,7 +775,7 @@ clang::Expr *Utils::isWriteOperator(Stmt *stm)
         return up->getSubExpr();
     }
 
-    if (BinaryOperator *bp = dyn_cast<BinaryOperator>(stm))
+    if (auto bp = dyn_cast<BinaryOperator>(stm))
         return bp->getLHS();
 
     return nullptr;
@@ -759,7 +789,7 @@ bool Utils::referencesVarDecl(clang::DeclStmt *declStmt, clang::VarDecl *varDecl
     if (declStmt->isSingleDecl() && declStmt->getSingleDecl() == varDecl)
         return true;
 
-    return clazy_std::any_of(declStmt->getDeclGroup(), [varDecl](Decl *decl) {
+    return clazy::any_of(declStmt->getDeclGroup(), [varDecl](Decl *decl) {
         return varDecl == decl;
     });
 }
@@ -768,26 +798,19 @@ UserDefinedLiteral *Utils::userDefinedLiteral(Stmt *stm, const std::string &type
 {
     auto udl = dyn_cast<UserDefinedLiteral>(stm);
     if (!udl)
-        udl = HierarchyUtils::getFirstChildOfType<UserDefinedLiteral>(stm);
+        udl = clazy::getFirstChildOfType<UserDefinedLiteral>(stm);
 
-    if (udl && StringUtils::returnTypeName(udl, lo) == type) {
+    if (udl && clazy::returnTypeName(udl, lo) == type) {
         return udl;
     }
 
     return nullptr;
 }
 
-#if LLVM_VERSION_MAJOR == 3 && LLVM_VERSION_MINOR <= 8
-clang::FunctionDecl::param_range Utils::functionParameters(clang::FunctionDecl *func)
-{
-    return func->params();
-}
-#else
 clang::ArrayRef<clang::ParmVarDecl *> Utils::functionParameters(clang::FunctionDecl *func)
 {
     return func->parameters();
 }
-#endif
 
 vector<CXXCtorInitializer *> Utils::ctorInitializer(CXXConstructorDecl *ctor, clang::ParmVarDecl *param)
 {
@@ -799,7 +822,7 @@ vector<CXXCtorInitializer *> Utils::ctorInitializer(CXXConstructorDecl *ctor, cl
     for (auto it = ctor->init_begin(), end = ctor->init_end(); it != end; ++it) {
         auto ctorInit = *it;
         vector<DeclRefExpr*> declRefs;
-        HierarchyUtils::getChilds(ctorInit->getInit(), declRefs);
+        clazy::getChilds(ctorInit->getInit(), declRefs);
         for (auto declRef : declRefs) {
             if (declRef->getDecl() == param) {
                 result.push_back(ctorInit);
@@ -817,7 +840,7 @@ bool Utils::ctorInitializerContainsMove(CXXCtorInitializer *init)
         return false;
 
     vector<CallExpr*> calls;
-    HierarchyUtils::getChilds(init->getInit(), calls);
+    clazy::getChilds(init->getInit(), calls);
 
     for (auto call : calls) {
         if (FunctionDecl *funcDecl = call->getDirectCallee()) {
@@ -832,7 +855,7 @@ bool Utils::ctorInitializerContainsMove(CXXCtorInitializer *init)
 
 bool Utils::ctorInitializerContainsMove(const vector<CXXCtorInitializer*> &ctorInits)
 {
-    return clazy_std::any_of(ctorInits, [](CXXCtorInitializer *ctorInit) {
+    return clazy::any_of(ctorInits, [](CXXCtorInitializer *ctorInit) {
         return Utils::ctorInitializerContainsMove(ctorInit);
     });
 }
@@ -840,7 +863,7 @@ bool Utils::ctorInitializerContainsMove(const vector<CXXCtorInitializer*> &ctorI
 string Utils::filenameForLoc(SourceLocation loc, const clang::SourceManager &sm)
 {
     string filename = sm.getFilename(loc);
-    auto splitted = clazy_std::splitString(filename, '/');
+    auto splitted = clazy::splitString(filename, '/');
     if (splitted.empty())
         return {};
 
@@ -885,3 +908,24 @@ SourceLocation Utils::locForNextToken(SourceLocation loc, const clang::SourceMan
 
     return loc.getLocWithOffset(Tok.getLength() + NumWhitespaceChars);
 }
+
+bool Utils::literalContainsEscapedBytes(StringLiteral *lt, const SourceManager &sm, const LangOptions &lo)
+{
+    if (!lt)
+        return false;
+
+    // The AST doesn't have the info, we need to ask the Lexer
+    SourceRange sr = lt->getSourceRange();
+    CharSourceRange cr = Lexer::getAsCharRange(sr, sm, lo);
+    const StringRef str = Lexer::getSourceText(cr, sm, lo);
+
+    for (int i = 0, size = str.size(); i < size - 1; ++i) {
+        if (str[i] == '\\') {
+            auto next = str[i+1];
+            if (next == 'U' || next == 'u' || next == 'x' || std::isdigit(next))
+                return true;
+        }
+    }
+
+    return false;
+}
