@@ -41,9 +41,15 @@ class CXXMethodDecl;
 class DetachingBase : public CheckBase
 {
 public:
-    explicit DetachingBase(const std::string &name, ClazyContext *context);
+    explicit DetachingBase(const std::string &name, ClazyContext *context, Options = Option_None);
 protected:
-    bool isDetachingMethod(clang::CXXMethodDecl *) const;
+
+    enum DetachingMethodType {
+        DetachingMethod,
+        DetachingMethodWithConstCounterPart
+    };
+
+    bool isDetachingMethod(clang::CXXMethodDecl *, DetachingMethodType = DetachingMethod) const;
 };
 
 #endif
