@@ -28,12 +28,14 @@
 /**
  * See README-connect-3arg-lambda.md for more info.
  */
-class Connect3argLambda : public CheckBase
+class Connect3ArgLambda : public CheckBase
 {
 public:
-    explicit Connect3argLambda(const std::string &name, ClazyContext *context);
+    explicit Connect3ArgLambda(const std::string &name, ClazyContext *context);
     void VisitStmt(clang::Stmt *stmt) override;
 private:
+    void processQTimer(clang::FunctionDecl *, clang::Stmt *);
+    void processQMenu(clang::FunctionDecl *, clang::Stmt *);
 };
 
 #endif
