@@ -1,7 +1,7 @@
 /*
    This file is part of the clazy static checker.
 
-  Copyright (C) 2016-2017 Sergio Martins <smartins@kde.org>
+  Copyright (C) 2016-2018 Sergio Martins <smartins@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -21,10 +21,10 @@
 
 #include "function-args-by-value.h"
 #include "Utils.h"
-#include "checkmanager.h"
 #include "StringUtils.h"
 #include "TypeUtils.h"
 #include "FixItUtils.h"
+#include "ClazyContext.h"
 
 #include <clang/AST/AST.h>
 #include <clang/Lex/Lexer.h>
@@ -32,11 +32,6 @@
 using namespace clang;
 using namespace std;
 
-enum Fixit {
-    FixitNone = 0,
-    FixitAll = 0x1 // More granularity isn't needed I guess
-};
-
 // TODO, go over all these
 static bool shouldIgnoreClass(CXXRecordDecl *record)
 {
@@ -58,13 +53,19 @@ static bool shouldIgnoreClass(CXXRecordDecl *record)
                                               "QVariantComparisonHelper",
                                               "QHashDummyValue", "QCharRef", "QString::Null"
                                              };
-    return clazy_std::contains(ignoreList, record->getQualifiedNameAsString());
+    return clazy::contains(ignoreList, record->getQualifiedNameAsString());
+}
+
+static bool shouldIgnoreOperator(FunctionDecl *function)
+{
+    // Too many warnings in operator<<
+    static const vector<StringRef> ignoreList = { "operator<<" };
+
+    return clazy::contains(ignoreList, clazy::name(function));
 }
 
 static bool shouldIgnoreFunction(clang::FunctionDecl *function)
 {
-    // Too many warnings in operator<<
-    static const vector<string> ignoreList = {"operator<<"};
     static const vector<string> qualifiedIgnoreList = {"QDBusMessage::createErrorReply", // Fixed in Qt6
                                                        "QMenu::exec", // Fixed in Qt6
                                                        "QTextFrame::iterator", // Fixed in Qt6
@@ -76,14 +77,12 @@ static bool shouldIgnoreFunction(clang::FunctionDecl *function)
                                                        "QSslCertificate::verify", // Fixed in Qt6
                                                        "QSslConfiguration::setAllowedNextProtocols" // Fixed in Qt6
                                                       };
-    if (clazy_std::contains(ignoreList, function->getNameAsString()))
-        return true;
 
-    return clazy_std::contains(qualifiedIgnoreList, function->getQualifiedNameAsString());
+    return clazy::contains(qualifiedIgnoreList, function->getQualifiedNameAsString());
 }
 
 FunctionArgsByValue::FunctionArgsByValue(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
+    : CheckBase(name, context, Option_CanIgnoreIncludes)
 {
 }
 
@@ -94,22 +93,31 @@ void FunctionArgsByValue::VisitDecl(Decl *decl)
 
 void FunctionArgsByValue::VisitStmt(Stmt *stmt)
 {
-    if (LambdaExpr *lambda = dyn_cast<LambdaExpr>(stmt))
+    if (auto lambda = dyn_cast<LambdaExpr>(stmt))
         processFunction(lambda->getCallOperator());
 }
 
 void FunctionArgsByValue::processFunction(FunctionDecl *func)
 {
-    if (!func || !func->isThisDeclarationADefinition() ||
-        func->isDeleted() || shouldIgnoreFunction(func))
+    if (!func || !func->isThisDeclarationADefinition() || func->isDeleted())
         return;
 
     auto ctor = dyn_cast<CXXConstructorDecl>(func);
-    if (ctor) {
-        if (ctor->isCopyConstructor())
-            return; // copy-ctor must take by ref
+    if (ctor && ctor->isCopyConstructor())
+        return; // copy-ctor must take by ref
+
+    const bool warnForOverriddenMethods = isOptionSet("warn-for-overridden-methods");
+    if (!warnForOverriddenMethods && Utils::methodOverrides(dyn_cast<CXXMethodDecl>(func))) {
+        // When overriding you can't change the signature. You should fix the base classes first
+        return;
     }
 
+    if (shouldIgnoreOperator(func))
+        return;
+
+    if (m_context->isQtDeveloper() && shouldIgnoreFunction(func))
+        return;
+
     Stmt *body = func->getBody();
 
     int i = -1;
@@ -124,7 +132,7 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
             continue;
 
         TypeUtils::QualTypeClassification classif;
-        bool success = TypeUtils::classifyQualType(&m_astContext, param, classif, body);
+        bool success = TypeUtils::classifyQualType(m_context, param, classif, body);
         if (!success)
             continue;
 
@@ -151,9 +159,11 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
             }
 
             std::vector<FixItHint> fixits;
-            if (isFixitEnabled(FixitAll)) {
+            auto method = dyn_cast<CXXMethodDecl>(func);
+            const bool isVirtualMethod = method && method->isVirtual();
+            if ((!isVirtualMethod || warnForOverriddenMethods) && isFixitEnabled()) { // Don't try to fix virtual methods, as build can fail
                 for (auto redecl : func->redecls()) { // Fix in both header and .cpp
-                    FunctionDecl *fdecl = dyn_cast<FunctionDecl>(redecl);
+                    auto fdecl = dyn_cast<FunctionDecl>(redecl);
                     const ParmVarDecl *param = fdecl->getParamDecl(i);
                     fixits.push_back(fixit(fdecl, param, classif));
                 }
@@ -161,7 +171,7 @@ void FunctionArgsByValue::processFunction(FunctionDecl *func)
 
             const string paramStr = param->getType().getAsString();
             string error = "Pass small and trivially-copyable type by value (" + paramStr + ')';
-            emitWarning(param->getLocStart(), error.c_str(), fixits);
+            emitWarning(getLocStart(param), error.c_str(), fixits);
         }
     }
 }
@@ -173,15 +183,15 @@ FixItHint FunctionArgsByValue::fixit(FunctionDecl *func, const ParmVarDecl *para
     qt.removeLocalConst();
     const string typeName = qt.getAsString(PrintingPolicy(lo()));
     string replacement = typeName + ' ' + string(param->getName());
-    SourceLocation startLoc = param->getLocStart();
-    SourceLocation endLoc = param->getLocEnd();
+    SourceLocation startLoc = getLocStart(param);
+    SourceLocation endLoc = getLocEnd(param);
 
     const int numRedeclarations = std::distance(func->redecls_begin(), func->redecls_end());
     const bool definitionIsAlsoDeclaration = numRedeclarations == 1;
     const bool isDeclarationButNotDefinition = !func->doesThisDeclarationHaveABody();
 
     if (param->hasDefaultArg() && (isDeclarationButNotDefinition || definitionIsAlsoDeclaration)) {
-        endLoc = param->getDefaultArg()->getLocStart().getLocWithOffset(-1);
+        endLoc = getLocStart(param->getDefaultArg()).getLocWithOffset(-1);
         replacement += " =";
     }
 
@@ -191,7 +201,5 @@ FixItHint FunctionArgsByValue::fixit(FunctionDecl *func, const ParmVarDecl *para
         return {};
     }
 
-    return FixItUtils::createReplacement({ startLoc, endLoc }, replacement);
+    return clazy::createReplacement({ startLoc, endLoc }, replacement);
 }
-
-REGISTER_CHECK("function-args-by-value", FunctionArgsByValue, CheckLevel2)
