@@ -32,10 +32,10 @@ RuleOfBase::RuleOfBase(const std::string &name, ClazyContext *context)
 
 bool RuleOfBase::isBlacklisted(CXXRecordDecl *record) const
 {
-    if (!record || clazy_std::startsWith(record->getQualifiedNameAsString(), "std::"))
+    if (!record || clazy::startsWith(record->getQualifiedNameAsString(), "std::"))
         return true;
 
-    const auto qualifiedName = StringUtils::classNameFor(record);
+    const auto qualifiedName = clazy::classNameFor(record);
 
     static const vector<string> blacklisted = { "QAtomicInt", "QBasicAtomicInteger", "QAtomicInteger", "QBasicAtomicPointer",
                                                 "QList::iterator", "QList::const_iterator", "QTextBlock::iterator",
@@ -61,5 +61,5 @@ bool RuleOfBase::isBlacklisted(CXXRecordDecl *record) const
                                                 "QBitRef", "QJsonValueRef",
                                                 "QTypedArrayData::iterator"
                                               };
-    return clazy_std::contains(blacklisted, qualifiedName);
+    return clazy::contains(blacklisted, qualifiedName);
 }
